@@ -42,6 +42,23 @@ static const std::string uiFile
     = PACKAGE_DATA_DIR"/"PACKAGE_TARNAME"/ui/"
           PACKAGE_TARNAME"-enlarged-renderer.ui";
 
+static void
+image_view_on_scroll_event(GtkImageView * view,
+                           GdkScrollDirection direction,
+                           gpointer user_data) throw()
+{
+    if (0 == user_data)
+    {
+        g_warning("Not an instance of EnlargedRenderer");
+        return;
+    }
+
+    EnlargedRenderer * enlarged_renderer
+        = static_cast<EnlargedRenderer *>(user_data);
+
+    enlarged_renderer->on_scroll_event(direction);
+}
+
 EnlargedRenderer::EnlargedRenderer() throw() :
     Renderer(),
     sigc::trackable(),
@@ -89,6 +106,62 @@ EnlargedRenderer::EnlargedRenderer() throw() :
         Gtk::Action::create(
             "ActionMenuGo", _("_Go")));
 
+    {
+        ActionPtr action = Gtk::Action::create(
+            "ActionViewZoomIn", Gtk::Stock::ZOOM_IN,
+            _("_Zoom In"),
+            _("Enlarge the photo"));
+
+        action->property_short_label().set_value(_("In"));
+        action->property_is_important().set_value(true);
+        actionGroup_->add(
+            action, Gtk::AccelKey("<control>plus"),
+            sigc::mem_fun(*this,
+                          &EnlargedRenderer::on_action_view_zoom_in));
+    }
+
+    {
+        ActionPtr action = Gtk::Action::create(
+            "ActionViewZoomOut", Gtk::Stock::ZOOM_OUT,
+            _("Zoom _Out"),
+            _("Shrink the photo"));
+
+        action->property_short_label().set_value(_("Out"));
+        action->property_is_important().set_value(true);
+        actionGroup_->add(
+            action, Gtk::AccelKey("<control>minus"),
+            sigc::mem_fun(*this,
+                &EnlargedRenderer::on_action_view_zoom_out));
+    }
+
+    {
+        ActionPtr action = Gtk::Action::create(
+            "ActionViewNormalSize", Gtk::Stock::ZOOM_100,
+            _("_Normal Size"),
+            _("Show the photo at its normal size"));
+
+        action->property_short_label().set_value(_("Normal"));
+        action->property_is_important().set_value(true);
+        actionGroup_->add(
+            action, Gtk::AccelKey("<control>0"),
+            sigc::mem_fun(*this,
+                &EnlargedRenderer::on_action_view_normal_size));
+    }
+
+    {
+        ActionPtr action = Gtk::Action::create(
+            "ActionViewBestFit", Gtk::Stock::ZOOM_FIT,
+            _("Best _Fit"),
+            _("Fit the photo to the window"));
+
+        action->property_short_label().set_value(_("Fit"));
+        action->property_is_important().set_value(true);
+        actionGroup_->add(
+            action,
+            sigc::mem_fun(*this,
+                &EnlargedRenderer::on_action_view_best_fit));
+    }
+
     {
         ActionPtr action = Gtk::Action::create(
             "ActionViewReload", Gtk::Stock::REFRESH,
@@ -147,6 +220,84 @@ EnlargedRenderer::EnlargedRenderer() throw() :
         Gtk::AccelKey("<alt>End"),
         sigc::mem_fun(*this, &EnlargedRenderer::on_action_go_last));
 
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelGoPrevious", Gtk::StockID(),
+            _("_Previous Photo"),
+            _("Go to the previous photo in the collection")),
+        Gtk::AccelKey("Left"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_go_previous));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelGoNext", Gtk::StockID(),
+            _("_Next Photo"),
+            _("Go to the next photo in the collection")),
+        Gtk::AccelKey("Right"),
+        sigc::mem_fun(*this, &EnlargedRenderer::on_action_go_next));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelGoFirst", Gtk::StockID(),
+            _("_First Photo"),
+            _("Go to the first photo in the collection")),
+        Gtk::AccelKey("Home"),
+        sigc::mem_fun(*this, &EnlargedRenderer::on_action_go_first));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelGoLast", Gtk::StockID(),
+            _("_Last Photo"),
+            _("Go to the last photo in the collection")),
+        Gtk::AccelKey("End"),
+        sigc::mem_fun(*this, &EnlargedRenderer::on_action_go_last));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelViewZoomIn", Gtk::StockID(),
+            _("_Zoom In"),
+            _("Enlarge the photo")),
+        Gtk::AccelKey("plus"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_view_zoom_in));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelViewZoomIn1", Gtk::StockID(),
+            _("_Zoom In"),
+            _("Enlarge the photo")),
+        Gtk::AccelKey("KP_Add"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_view_zoom_in));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelViewZoomIn2", Gtk::StockID(),
+            _("_Zoom In"),
+            _("Enlarge the photo")),
+        Gtk::AccelKey("equal"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_view_zoom_in));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelViewZoomOut", Gtk::StockID(),
+            _("Zoom _Out"),
+            _("Shrink the photo")),
+        Gtk::AccelKey("minus"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_view_zoom_out));
+
+    actionGroup_->add(
+        Gtk::Action::create(
+            "AccelViewZoomOut1", Gtk::StockID(),
+            _("Zoom _Out"),
+            _("Shrink the photo")),
+        Gtk::AccelKey("KP_Subtract"),
+        sigc::mem_fun(*this,
+                      &EnlargedRenderer::on_action_view_zoom_out));
+
     dockItem_ = gdl_dock_item_new_with_stock(dockItemName_.c_str(),
                     dockItemTitle_.c_str(),
                     PACKAGE_TARNAME"-mode-image-edit",
@@ -231,6 +382,17 @@ EnlargedRenderer::render(const PhotoPtr & photo) throw()
 
         // Get rid of some of the default keybindings.
 
+        gtk_binding_entry_remove(binding_set, GDK_KP_Add,
+                                 static_cast<GdkModifierType>(0));
+        gtk_binding_entry_remove(binding_set, GDK_equal,
+                                 static_cast<GdkModifierType>(0));
+        gtk_binding_entry_remove(binding_set, GDK_plus,
+                                 static_cast<GdkModifierType>(0));
+        gtk_binding_entry_remove(binding_set, GDK_KP_Subtract,
+                                 static_cast<GdkModifierType>(0));
+        gtk_binding_entry_remove(binding_set, GDK_minus,
+                                 static_cast<GdkModifierType>(0));
+
         gtk_binding_entry_remove(binding_set, GDK_Right,
                                  static_cast<GdkModifierType>(0));
         gtk_binding_entry_remove(binding_set, GDK_Left,
@@ -242,9 +404,11 @@ EnlargedRenderer::render(const PhotoPtr & photo) throw()
 
         Gtk::Widget * image_view = Glib::wrap(GTK_WIDGET(imageView_),
                                               false);
-        image_view->signal_key_press_event().connect(
-            sigc::mem_fun(*this,
-                          &EnlargedRenderer::on_key_press_event));
+
+        g_signal_connect(GTK_IMAGE_VIEW(imageView_),
+                         "mouse-wheel-scroll",
+                         G_CALLBACK(image_view_on_scroll_event),
+                         this);
     }
 
     if (0 == imageScrollWin_)
@@ -471,32 +635,72 @@ EnlargedRenderer::on_action_view_reload() throw()
     engine.selection_changed().emit();
 }
 
-bool
-EnlargedRenderer::on_key_press_event(GdkEventKey * event) throw()
+void
+EnlargedRenderer::on_action_view_best_fit() throw()
 {
-    switch (event->keyval)
+    if (0 == imageView_)
     {
-        case GDK_Right:
-            on_action_go_next();
-            break;
-
-        case GDK_Left:
-            on_action_go_previous();
-            break;
-
-        case GDK_Home:
-            on_action_go_first();
-            break;
-
-        case GDK_End:
-            on_action_go_last();
-            break;
-
-        default:
-            break;
+        return;
     }
 
-    return true;
+    if (false == GTK_IS_IMAGE_VIEW(imageView_))
+    {
+        g_warning("Not a GtkImageView");
+        return;
+    }
+
+    gtk_image_view_set_fitting(GTK_IMAGE_VIEW(imageView_), TRUE);
+}
+
+void
+EnlargedRenderer::on_action_view_normal_size() throw()
+{
+    if (0 == imageView_)
+    {
+        return;
+    }
+
+    if (false == GTK_IS_IMAGE_VIEW(imageView_))
+    {
+        g_warning("Not a GtkImageView");
+        return;
+    }
+
+    gtk_image_view_set_zoom(GTK_IMAGE_VIEW(imageView_), 1.0);
+}
+
+void
+EnlargedRenderer::on_action_view_zoom_in() throw()
+{
+    if (0 == imageView_)
+    {
+        return;
+    }
+
+    if (false == GTK_IS_IMAGE_VIEW(imageView_))
+    {
+        g_warning("Not a GtkImageView");
+        return;
+    }
+
+    gtk_image_view_zoom_in(GTK_IMAGE_VIEW(imageView_));
+}
+
+void
+EnlargedRenderer::on_action_view_zoom_out() throw()
+{
+    if (0 == imageView_)
+    {
+        return;
+    }
+
+    if (false == GTK_IS_IMAGE_VIEW(imageView_))
+    {
+        g_warning("Not a GtkImageView");
+        return;
+    }
+
+    gtk_image_view_zoom_out(GTK_IMAGE_VIEW(imageView_));
 }
 
 void
@@ -537,6 +741,24 @@ EnlargedRenderer::on_item_activated(const Gtk::TreeIter & iter)
     main_window.present_dock_object(GDL_DOCK_OBJECT(dockItem_));
 }
 
+void
+EnlargedRenderer::on_scroll_event(GdkScrollDirection direction) throw()
+{
+    switch (direction)
+    {
+        case GDK_SCROLL_UP:
+            on_action_view_zoom_in();
+            break;
+
+        case GDK_SCROLL_DOWN:
+            on_action_view_zoom_out();
+            break;
+
+        default:
+            break;
+    }
+}
+
 void
 EnlargedRenderer::on_switch_page(GtkNotebookPage * notebook_page,
                                  guint page_num) throw()
